@@ -21,7 +21,7 @@ class PML2PMLZ(FileTypePlugin):
     name = 'PML to PMLZ'
     author = 'John Schember'
     description = _('Create a PMLZ archive containing the PML file '
-        'and all images in the directory pmlname_img or images. '
+        'and all images in the folder pmlname_img or images. '
         'This plugin is run every time you add '
         'a PML file to the library.')
     version = numeric_version
@@ -970,6 +970,12 @@ class ActionOpenFolder(InterfaceActionBase):
             ' calibre library')
 
 
+class ActionAutoscrollBooks(InterfaceActionBase):
+    name = 'Autoscroll Books'
+    actual_plugin = 'calibre.gui2.actions.auto_scroll:AutoscrollBooksAction'
+    description = _('Auto scroll through the list of books')
+
+
 class ActionSendToDevice(InterfaceActionBase):
     name = 'Send To Device'
     actual_plugin = 'calibre.gui2.actions.device:SendToDeviceAction'
@@ -1115,7 +1121,7 @@ plugins += [ActionAdd, ActionFetchAnnotations, ActionGenerateCatalog,
         ActionCopyToLibrary, ActionTweakEpub, ActionUnpackBook, ActionNextMatch, ActionStore,
         ActionPluginUpdater, ActionPickRandom, ActionEditToC, ActionSortBy,
         ActionMarkBooks, ActionEmbed, ActionTemplateTester, ActionTagMapper, ActionAuthorMapper,
-        ActionVirtualLibrary, ActionBrowseAnnotations, ActionTemplateFunctions]
+        ActionVirtualLibrary, ActionBrowseAnnotations, ActionTemplateFunctions, ActionAutoscrollBooks]
 
 # }}}
 
