@@ -11,7 +11,7 @@ from contextlib import contextmanager
 
 from html5_parser import parse
 from lxml import html
-from PyQt5.Qt import (
+from qt.core import (
     QAction, QApplication, QBrush, QByteArray, QCheckBox, QColor, QColorDialog,
     QDialog, QDialogButtonBox, QFont, QFontInfo, QFontMetrics, QFormLayout,
     QHBoxLayout, QIcon, QKeySequence, QLabel, QLineEdit, QMenu, QPalette,
@@ -457,9 +457,10 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
 
     def do_alignment(self, which):
         with self.editing_cursor() as c:
+            c = self.textCursor()
             fmt = QTextBlockFormat()
             fmt.setAlignment(which)
-            c.setBlockFormat(fmt)
+            c.mergeBlockFormat(fmt)
 
     def do_align_left(self):
         self.do_alignment(Qt.AlignmentFlag.AlignLeft)
