@@ -10,7 +10,7 @@ from collections import OrderedDict, namedtuple
 from functools import partial
 from polyglot.builtins import iteritems, itervalues, zip, unicode_type, range, map
 
-from PyQt5.Qt import (
+from qt.core import (
     QDialog, QWidget, QGridLayout, QLabel, QToolButton, QIcon,
     QVBoxLayout, QDialogButtonBox, QApplication, pyqtSignal, QFont, QPixmap,
     QSize, QPainter, Qt, QColor, QPen, QSizePolicy, QScrollArea,
@@ -93,6 +93,11 @@ class LineEdit(EditWithComplete):
         self.setText(val)
         self.setCursorPosition(0)
 
+    def set_undoable(self, val):
+        self.selectAll()
+        self.insert(val)
+        self.setCursorPosition(0)
+
     @property
     def is_blank(self):
         val = self.current_val.strip()
@@ -138,6 +143,9 @@ class LanguagesEdit(LE):
     def same_as(self, other):
         return self.current_val == other.current_val
 
+    def set_undoable(self, val):
+        self.set_lang_codes(val, True)
+
 
 class RatingsEdit(RatingEdit):
 
@@ -191,6 +199,9 @@ class DateEdit(PubdateEdit):
     def same_as(self, other):
         return self.text() == other.text()
 
+    def set_undoable(self, val):
+        self.set_value(val)
+
 
 class SeriesEdit(LineEdit):
 
@@ -274,6 +285,10 @@ class CommentsEdit(Editor):
         self.html = val or ''
         self.changed.emit()
 
+    def set_undoable(self, val):
+        self.set_html(val, allow_undo=True)
+        self.changed.emit()
+
     def from_mi(self, mi):
         val = mi.get(self.field, default='')
         self.current_val = val
@@ -486,7 +501,10 @@ class CompareSingle(QWidget):
     def revert(self, field):
         widgets = self.widgets[field]
         neww, oldw = widgets[:2]
-        neww.current_val = oldw.current_val
+        if hasattr(neww, 'set_undoable'):
+            neww.set_undoable(oldw.current_val)
+        else:
+            neww.current_val = oldw.current_val
 
     def merge_identifiers(self):
         widgets = self.widgets['identifiers']
@@ -560,17 +578,17 @@ class CompareMany(QDialog):
         bb.button(QDialogButtonBox.StandardButton.Cancel).setAutoDefault(False)
         bb.rejected.connect(self.reject)
         if self.total > 1:
-            self.aarb = b = bb.addButton(_('&Accept all remaining'), bb.YesRole)
+            self.aarb = b = bb.addButton(_('&Accept all remaining'), QDialogButtonBox.ButtonRole.YesRole)
             b.setIcon(QIcon(I('ok.png'))), b.setAutoDefault(False)
             if accept_all_tooltip:
                 b.setToolTip(accept_all_tooltip)
             b.clicked.connect(self.accept_all_remaining)
-            self.rarb = b = bb.addButton(_('Re&ject all remaining'), bb.ActionRole)
+            self.rarb = b = bb.addButton(_('Re&ject all remaining'), QDialogButtonBox.ButtonRole.ActionRole)
             b.setIcon(QIcon(I('minus.png'))), b.setAutoDefault(False)
             if reject_all_tooltip:
                 b.setToolTip(reject_all_tooltip)
             b.clicked.connect(self.reject_all_remaining)
-            self.sb = b = bb.addButton(_('R&eject'), bb.ActionRole)
+            self.sb = b = bb.addButton(_('R&eject'), QDialogButtonBox.ButtonRole.ActionRole)
             connect_lambda(b.clicked, self, lambda self: self.next_item(False))
             b.setIcon(QIcon(I('minus.png'))), b.setAutoDefault(False)
             if reject_button_tooltip:
@@ -579,11 +597,11 @@ class CompareMany(QDialog):
             ac.setShortcut(QKeySequence(Qt.Modifier.ALT | Qt.Key.Key_Right))
             self.addAction(ac)
         if action_button is not None:
-            self.acb = b = bb.addButton(action_button[0], bb.ActionRole)
+            self.acb = b = bb.addButton(action_button[0], QDialogButtonBox.ButtonRole.ActionRole)
             b.setIcon(QIcon(action_button[1]))
             self.action_button_action = action_button[2]
             b.clicked.connect(self.action_button_clicked)
-        self.nb = b = bb.addButton(_('&Next') if self.total > 1 else _('&OK'), bb.ActionRole)
+        self.nb = b = bb.addButton(_('&Next') if self.total > 1 else _('&OK'), QDialogButtonBox.ButtonRole.ActionRole)
         if self.total > 1:
             b.setToolTip(_('Move to next [%s]') % self.next_action.shortcut().toString(QKeySequence.SequenceFormat.NativeText))
             self.next_action.triggered.connect(b.click)
