@@ -3,7 +3,7 @@
 # License: GPLv3 Copyright: 2016, Kovid Goyal <kovid at kovidgoyal.net>
 
 
-import unittest, functools, os, importlib, zipfile
+import unittest, functools, importlib
 from calibre.utils.monotonic import monotonic
 
 
@@ -53,23 +53,18 @@ class TestResult(unittest.TextTestResult):
                 self.stream.writeln('\nSlowest tests: %s' % ' '.join(slowest))
 
 
-def find_tests_in_dir(path, excludes=('main.py',)):
-    if not os.path.exists(path) and '.zip' in path:
-        idx = path.rfind('.zip')
-        zf = path[:idx+4]
-        prefix = os.path.relpath(path, zf).replace(os.sep, '/')
-        package = prefix.replace('/', '.')
-        with zipfile.ZipFile(zf) as f:
-            namelist = f.namelist()
-        items = [i for i in namelist if i.startswith(prefix) and i.count('/') == prefix.count('/') + 1]
-    else:
-        d = os.path.dirname
-        base = d(d(d(os.path.abspath(__file__))))
-        package = os.path.relpath(path, base).replace(os.sep, '/').replace('/', '.')
-        items = os.listdir(path)
+def find_tests_in_package(package, excludes=('main.py',)):
+    loader = importlib.import_module(package).__spec__.loader
+    items = list(loader.contents())
     suits = []
+    excludes = set(excludes) | {x + 'c' for x in excludes}
+    seen = set()
     for x in items:
-        if x.endswith('.py') and x not in excludes:
+        if (x.endswith('.py') or x.endswith('.pyc')) and x not in excludes:
+            q = x.rpartition('.')[0]
+            if q in seen:
+                continue
+            seen.add(q)
             m = importlib.import_module(package + '.' + x.partition('.')[0])
             suits.append(unittest.defaultTestLoader.loadTestsFromModule(m))
     return unittest.TestSuite(suits)
@@ -113,6 +108,14 @@ def filter_tests_by_name(suite, *names):
     return filter_tests(suite, q)
 
 
+def remove_tests_by_name(suite, *names):
+    names = {x if x.startswith('test_') else 'test_' + x for x in names}
+
+    def q(test):
+        return test._testMethodName not in names
+    return filter_tests(suite, q)
+
+
 def filter_tests_by_module(suite, *names):
     names = frozenset(names)
 
@@ -139,10 +142,10 @@ def run_tests(find_tests, verbosity=4):
     run_cli(tests, verbosity)
 
 
-def run_cli(suite, verbosity=4):
+def run_cli(suite, verbosity=4, buffer=True):
     r = unittest.TextTestRunner
     r.resultclass = unittest.TextTestResult if verbosity < 2 else TestResult
     init_env()
-    result = r(verbosity=verbosity).run(suite)
+    result = r(verbosity=verbosity, buffer=buffer).run(suite)
     if not result.wasSuccessful():
         raise SystemExit(1)
